#' @title Create TPP-CCR config files for 2D-TPP experiment
#' @description Creates a list of config files for the TPP-CCR analysis so that the config files in the 
#'  list matches the data.list generated by the 2D-TPP workflow.  
#'  
#' @return A config file of type data.frame which can be used for the \code{\link{tpp2dCurveFit}} function
#'  
#' @examples
#'   data("panob2D_isobQuant_example")        
#'   CCRconfig <- tpp2dCreateCCRConfigFile(configTable = panobinostat_2DTPP_config)           
#' @param configTable data frame that specifies important details of the 2D-TPP experiment
#'   
#' @export
tpp2dCreateCCRConfigFile <- function(configTable){
  if (is.null(configTable) | !is.data.frame(configTable)){
    stop("Please specify a valid configTable of type data.frame!")
  }else{
    concentrations <- extractConc(configTable)
    exp.name <- configTable$Compound[1]
    concs <- unique(extractConc(configTable))
    names(concs) <- concs
    out <- data.frame(Experiment = exp.name, 
                      t(concs), 
                      check.names = FALSE, 
                      row.names = c(""))
    return(out) 
  }
}